=============
API Reference
=============


Scalar
======

.. autoclass:: barril.units.Scalar
    :members:

Array
=====

.. autoclass:: barril.units.Array
    :members:

FixedArray
==========

.. autoclass:: barril.units.FixedArray
    :members:

FractionScalar
==============

.. autoclass:: barril.units.FractionScalar
    :members:

UnitDatabase
============

.. autoclass:: barril.units.UnitDatabase
    :members:
